@@ -24,11 +24,11 @@
 #include <gnome.h>
 #include <gconf/gconf-client.h>
 #include <math.h>
-#include "eggtrayicon.h"
 #include "bacon-volume.h"
 #include "gui.h"
 #include "trayicon.h"
 #include "tech.h"
+#include "radio.h"
 #include "rec_tech.h"
 #include "lirc.h"
 #include "prefs.h"
@@ -47,6 +47,13 @@
 
 #define TRANSLATORS "TRANSLATORS"
 
+GtkWidget* mute_button, *preset_combo;
+GtkAdjustment *adj;
+GtkTooltips *tooltips;
+
+int mom_ps;
+gnomeradio_settings settings;
+
 static GtkWidget *drawing_area;
 static GdkPixmap *digits, *signal_s, *stereo;
 static GtkWidget *freq_scale;
@@ -107,7 +114,7 @@ static gboolean initial_frequency_scan_cb(gpointer data)
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(fsd->progress), MAX(0, (freq - FREQ_MIN)/(FREQ_MAX - FREQ_MIN)));	
 	
 	freq += 1.0/STEPS;
-	radio_setfreq(freq);
+	radio_set_freq(freq);
 	
 	return TRUE;
 }
@@ -154,7 +161,7 @@ static void initial_frequency_scan(GtkWidget *app)
 		if (g_list_length(data.stations) > 0) {
 			gfloat f = *((gfloat*)data.stations->data);
 			adj->value = f*STEPS;
-			radio_setfreq(f);
+			radio_set_freq(f);
 			
 			GtkWidget *dialog;
 			GList *ptr;
@@ -216,10 +223,18 @@ static void prefs_button_clicked_cb(GtkButton *button, gpointer app)
 
 void start_radio(gboolean restart, GtkWidget *app)
 {
+    DriverType driver = DRIVER_ANY;
 	if (restart)
 		radio_stop();
 	
-	if (!radio_init(settings.device)) 
+    if (settings.driver) {
+        if (0 == strcmp(settings.driver, "v4l1"))
+            driver = DRIVER_V4L1;
+        if (0 == strcmp(settings.driver, "v4l2"))
+            driver = DRIVER_V4L2;
+    }
+
+	if (!radio_init(settings.device, driver))
 	{
 		char *caption = g_strdup_printf(_("Could not open device \"%s\"!"), settings.device);
 		char *detail = g_strdup_printf(_("Check your settings and make sure that no other\n"
@@ -301,8 +316,8 @@ static gboolean redraw_status_window(void)
 	freq[3] = (val % 100) / 10;
 	freq[4] = val % 10;
 
-	signal_strength = radio_getsignal();
-	is_stereo = radio_getstereo();
+	signal_strength = radio_get_signal();
+	is_stereo = radio_get_stereo();
 	
 	if (signal_strength > 3) signal_strength = 3;
 	if (signal_strength < 0) signal_strength = 0;
@@ -395,14 +410,14 @@ static void adj_value_changed_cb(GtkAdjustment* data, gpointer window)
 	else
 		buffer = g_strdup_printf(_("Gnomeradio - %.2f MHz"), freq);
 	gtk_window_set_title(GTK_WINDOW(window), buffer);
-	if (tray_icon) gtk_tooltips_set_tip(tooltips, tray_icon, buffer, NULL);
+	if (tray_icon) gtk_status_icon_set_tooltip(GTK_STATUS_ICON(tray_icon), buffer); //gtk_tooltips_set_tip(tooltips, tray_icon, buffer, NULL);
 	g_free(buffer);
 	
 	buffer = g_strdup_printf(_("Frequency: %.2f MHz"), freq);
 	gtk_tooltips_set_tip(tooltips, freq_scale, buffer, NULL);
 	g_free(buffer);
 
-	radio_setfreq(adj->value/STEPS);
+	radio_set_freq(adj->value/STEPS);
 }
 
 static void volume_value_changed_cb(BaconVolumeButton *button, gpointer user_data)
@@ -416,10 +431,11 @@ static void volume_value_changed_cb(BaconVolumeButton *button, gpointer user_dat
 	gtk_tooltips_set_tip(tooltips, vol_scale, text, NULL);
 	g_free(text);*/
 	
-	g_assert(tray_menu);
-	g_signal_handler_block(G_OBJECT(mute_menuitem), mute_menuitem_toggled_cb_id);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mute_menuitem), vol == 0);
-	g_signal_handler_unblock(G_OBJECT(mute_menuitem), mute_menuitem_toggled_cb_id);
+    if (tray_menu) {
+	    g_signal_handler_block(G_OBJECT(mute_menuitem), mute_menuitem_toggled_cb_id);
+	    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mute_menuitem), vol == 0);
+	    g_signal_handler_unblock(G_OBJECT(mute_menuitem), mute_menuitem_toggled_cb_id);
+    }
 }
 
 #if 0
@@ -1078,6 +1094,7 @@ int main(int argc, char* argv[])
 	g_set_application_name(_("Gnomeradio"));
 	
 #if GNOME_14
+    if (!g_thread_supported ()) g_thread_init(NULL);
 	ctx = g_option_context_new("- Gnomeradio");
 	g_option_context_add_main_entries(ctx, entries, GETTEXT_PACKAGE);  
 	g_option_context_add_group(ctx, gst_init_get_option_group());
@@ -1113,15 +1130,6 @@ int main(int argc, char* argv[])
 	}
 
 	load_settings();
-	create_tray_menu(app);
-	
-	gtk_combo_box_append_text(GTK_COMBO_BOX(preset_combo), _("manual"));
-	for (ptr = settings.presets; ptr; ptr = g_list_next(ptr)) {
-		preset *ps = (preset*)ptr->data;
-		gtk_combo_box_append_text(GTK_COMBO_BOX(preset_combo), ps->title);
-	}
-	preset_combo_set_item(mom_ps);
-
 	start_mixer(FALSE, app);
 	start_radio(FALSE, app);
 	if (is_first_start() || do_scan) {
@@ -1132,6 +1140,15 @@ int main(int argc, char* argv[])
 			set_first_time_flag();
 		}
 	}
+	create_tray_menu(app);
+	
+	gtk_combo_box_append_text(GTK_COMBO_BOX(preset_combo), _("manual"));
+	for (ptr = settings.presets; ptr; ptr = g_list_next(ptr)) {
+		preset *ps = (preset*)ptr->data;
+		gtk_combo_box_append_text(GTK_COMBO_BOX(preset_combo), ps->title);
+	}
+	preset_combo_set_item(mom_ps);
+
 	gtk_widget_show_all(app);
 
 	/* Create an tray icon */
