@@ -33,7 +33,8 @@ struct Gnomeradio_Settings
 	gchar *mixer_dev;
 	gchar *mixer;
 	gboolean mute_on_exit;
-		
+    gchar *driver;
+	
 	GList *presets;
 };
 
@@ -43,15 +44,6 @@ struct Preset
 	gfloat freq;
 };
 
-GtkWidget* mute_button, *preset_combo;
-GtkAdjustment *adj;
-GtkTooltips *tooltips;
-
-
-int mom_ps;
-
-gnomeradio_settings settings;
-
 void start_radio(gboolean restart, GtkWidget *app);
 
 void start_mixer(gboolean restart, GtkWidget *app);
