@@ -23,6 +23,13 @@
 #include "gui.h"
 #include "rec_tech.h"
 
+extern GtkWidget* mute_button, *preset_combo;
+extern GtkAdjustment *adj;
+extern GtkTooltips *tooltips;
+
+extern int mom_ps;
+extern gnomeradio_settings settings;
+
 static GtkWidget *device_entry;
 static GtkWidget *mixer_combo;
 static GtkWidget *mute_on_exit_cb;
@@ -46,6 +53,7 @@ gboolean save_settings(void)
 	
 	/* Store general settings */
 	gconf_client_set_string(client, "/apps/gnomeradio/device", settings.device, NULL);
+	gconf_client_set_string(client, "/apps/gnomeradio/driver", settings.driver, NULL);
 	gconf_client_set_string(client, "/apps/gnomeradio/mixer", settings.mixer, NULL);
 	gconf_client_set_string(client, "/apps/gnomeradio/mixer-device", settings.mixer_dev, NULL);
 	gconf_client_set_bool(client, "/apps/gnomeradio/mute-on-exit", settings.mute_on_exit, NULL);
@@ -105,6 +113,9 @@ gboolean load_settings(void)
 	settings.device = gconf_client_get_string(client, "/apps/gnomeradio/device" , NULL);
 	if (!settings.device)
 		settings.device = g_strdup("/dev/radio");
+	settings.driver = gconf_client_get_string(client, "/apps/gnomeradio/driver" , NULL);
+	if (!settings.driver)
+		settings.driver = g_strdup("any");
 	settings.mixer = gconf_client_get_string(client, "/apps/gnomeradio/mixer", NULL);
 	if (!settings.mixer)
 		settings.mixer = g_strdup("line");
@@ -411,6 +422,7 @@ static void name_cell_edited_cb(GtkCellRendererText *cellrenderertext, gchar *pa
 
 	gtk_combo_box_remove_text(GTK_COMBO_BOX(preset_combo), *row + 1);
 	gtk_combo_box_insert_text(GTK_COMBO_BOX(preset_combo), *row + 1, ps->title);
+	mom_ps = *row;
 	preset_combo_set_item(mom_ps);
 	
 	menuitems = GTK_MENU_SHELL(tray_menu)->children;
