@@ -31,22 +31,4 @@ int mixer_get_volume(void);
 
 int mixer_set_rec_device(void);
 
-int radio_init(char *device);
-
-int radio_is_init(void);
-
-void radio_stop(void);
-
-int radio_setfreq(float freq);
-
-int radio_check_station(float freq);
-
-void radio_unmute();
-
-void radio_mute();
-
-int radio_getstereo();
-
-int radio_getsignal();
-
 #endif
